resolve_place_from_ident

Function resolve_place_from_ident 

pub(crate) fn resolve_place_from_ident<'tcx>(
    tcx: TyCtxt<'tcx>,
    def_id: DefId,
    base_ident: &str,
    fields: &[String],
) -> Option<(usize, Vec<(usize, Ty<'tcx>)>, Ty<'tcx>)>
Resolve a place given its base identifier and field-name list directly, without going through a syn expression. Used by the pest converter.