pub(crate) fn strip_for_each<'tcx>(
arg: &mut PropertyArg<'tcx>,
) -> Option<ContractPlace<'tcx>>Expand description
Strip ForEach from a property arg and return the container place
(without the projection) if ForEach was present.
pub(crate) fn strip_for_each<'tcx>(
arg: &mut PropertyArg<'tcx>,
) -> Option<ContractPlace<'tcx>>Strip ForEach from a property arg and return the container place
(without the projection) if ForEach was present.